CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_config.h File Reference

CCL

Data Structures | Typedefs | Enumerations | Variables
ccl_config.h File Reference

Go to the source code of this file.

## Data Structures
struct | ccl_configuration

## Typedefs
typedef enum transfer_function_t | transfer_function_t
typedef enum matter_power_spectrum_t | matter_power_spectrum_t
typedef enum mass_function_t | mass_function_t
typedef struct ccl_configuration | ccl_configuration

## Enumerations
enum | transfer_function_t { ccl_emulator = 0, ccl_none = 0, ccl_fitting_function = 1, ccl_eisenstein_hu = 1, ccl_bbks = 2, ccl_boltzmann = 3, ccl_boltzmann_class = 3, ccl_boltzmann_camb = 4 }
enum | matter_power_spectrum_t { ccl_linear = 0, ccl_halofit = 1, ccl_halo_model = 3 }
enum | mass_function_t { ccl_tinker = 1, ccl_tinker10 = 2, ccl_watson = 3, ccl_angulo = 4 }

## Variables
const ccl_configuration | default_config

## Typedef Documentation

## ◆ ccl_configuration

typedef struct ccl_configuration ccl_configuration

Configuration typedef. This contains the transfer function, matter power spectrum, and mass function that is being used currently.

## ◆ mass_function_t

typedef enum mass_function_t mass_function_t

Mass function typedef Contains all information that describes a specific mass function. This is basically a switch that chooses between Tinker08, Tinker10, Watson and Angulo mass functions.

## ◆ matter_power_spectrum_t

typedef enum matter_power_spectrum_t matter_power_spectrum_t

Matter power spectrum typedef. Contains all information that describes a specific matter power spectrum. This inclues whether we want the linear power spectrum, whether we use halofit, and what halo model is being used.

## ◆ transfer_function_t

typedef enum transfer_function_t transfer_function_t

Transfer function typedef. Contains all information that describes a specific transfer function. This includes whether there is an emulator being used (Note: not implemented yet), if there is a fitting function (E&H is the only option right now), whether to use the BBKS transfer function, and what boltzmann code to use.

## Enumeration Type Documentation

## ◆ mass_function_t

enum mass_function_t

Mass function typedef Contains all information that describes a specific mass function. This is basically a switch that chooses between Tinker08, Tinker10, Watson and Angulo mass functions.

Enumerator
ccl_tinker |
ccl_tinker10 |
ccl_watson |
ccl_angulo |

## ◆ matter_power_spectrum_t

enum matter_power_spectrum_t

Matter power spectrum typedef. Contains all information that describes a specific matter power spectrum. This inclues whether we want the linear power spectrum, whether we use halofit, and what halo model is being used.

Enumerator
ccl_linear |
ccl_halofit |
ccl_halo_model |

## ◆ transfer_function_t

enum transfer_function_t

Transfer function typedef. Contains all information that describes a specific transfer function. This includes whether there is an emulator being used (Note: not implemented yet), if there is a fitting function (E&H is the only option right now), whether to use the BBKS transfer function, and what boltzmann code to use.

Enumerator
ccl_emulator |
ccl_none |
ccl_fitting_function |
ccl_eisenstein_hu |
ccl_bbks |
ccl_boltzmann |
ccl_boltzmann_class |
ccl_boltzmann_camb |

## Variable Documentation

## ◆ default_config

const ccl_configuration default_config

The default configuration object In the default configuration, defined in ccl_core.c CCL runs with: default_config = {ccl_boltzmann_class, ccl_halofit, ccl_tinker10}